/***************************************************************************
    file:           ksensorssetting.h
    description:    settings management
    begin:          09/06/2024
    Copyright:      Giuseppe Della Bianca<giusdbg@gmail.com>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _KSENSORSSETTING_H_
#define _KSENSORSSETTING_H_

#include <qwidget.h>
#include <qcommandlineparser.h>

#include <KSharedConfig>
#include <kconfiggroup.h>
#include <kconfig.h>

#include <general.h>


class ksensorsSetting
{
public:
    enum Type 
    {
        Default = 0,
        AutoDefault = 1,
        OnlyDefault = 2,
        DeleteDefault = 3
    };

    enum Actions 
    {
        acNothing = 0,
        acSound = 1,
        acCommand = 2
    };

    ksensorsSetting();
    ~ksensorsSetting();

    void getDefaultPalette ( QPalette &pal );
    bool getPalette ( QPalette &pal, const QString &name, bool returnDefault );
    double getSettingUpdateInterval ( const QString &key, double Minimum, Type type );
    void setSensorDevGroupConf ( const QString &shortName, const QString longName, const QString subName );

    void setPar ( QCommandLineParser &parser );
    void setPar ( const QString &name, const bool value );
    void setPar ( const QString &name, const int value );
    bool getPar ( const QString &name, bool bDefault );
    int getPar ( const QString &name, int iDefault );

    void setGroupConf ( const QString &group );

    int getEntryConf ( const QString &keyIn, MeterTypes meterTypes, int iDefault, Type type );
    QString getEntryConf ( const QString &keyIn, MeterTypes meterTypes, QString qsDefault, Type type );
    QPoint getEntryConf ( const QString &keyIn, MeterTypes meterTypes, QPoint qpDefault, Type type );
    QRect getEntryConf ( const QString &keyIn, MeterTypes meterTypes, QRect qrDefault, Type type );

    bool getEntryConf ( const QString &key, bool bDefault, Type type );
    int getEntryConf ( const QString &key, int iDefault, Type type );
    double getEntryConf ( const QString &key, double dDefault, Type type );
    QString getEntryConf ( const QString &key, QString qsDefault, Type type );
    QColor getEntryConf ( const QString &key, QColor qcDefault, Type type );
    QPoint getEntryConf ( const QString &key, QPoint qpDefault, Type type );
    QRect getEntryConf ( const QString &key, QRect qrDefault, Type type );

    bool setEntryConf ( const QString &keyIn, MeterTypes meterTypes, const int value );
    bool setEntryConf ( const QString &keyIn, MeterTypes meterTypes, const QString &value );
    bool setEntryConf ( const QString &keyIn, MeterTypes meterTypes, const QPoint &value );
    bool setEntryConf ( const QString &keyIn, MeterTypes meterTypes, const QRect &value  );

    bool setEntryConf ( const QString &key, const bool value );
    bool setEntryConf ( const QString &key, const int value );
    bool setEntryConf ( const QString &key, const double value, double dDefault = -1.0, Type type = Type::Default );
    bool setEntryConf ( const QString &key, const QString &value );
    bool setEntryConf ( const QString &key, const QColor &value );
    bool setEntryConf ( const QString &key, const QPoint &value );
    bool setEntryConf ( const QString &key, const QRect &value );

    bool syncConf();

private:
    KSharedConfig::Ptr kscpConfig;
    KConfigGroup kcgConfig;

    static bool autoStartOpt;
    static bool noDockOpt;
    static bool showSplashOpt;
    static bool chartTestOpt;
};

#endif // _KSENSORSSETTING_H_
